@@ -2,18 +2,23 @@
 package MooseX::AttributeHelpers::Collection::Hash;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'Moose::Meta::Attribute';
-with 'MooseX::AttributeHelpers::Trait::Collection::Hash';
+use MooseX::AttributeHelpers::MethodProvider::Hash;
+
+extends 'MooseX::AttributeHelpers::Collection';
+
+has '+method_provider' => (
+    default => 'MooseX::AttributeHelpers::MethodProvider::Hash'
+);
+
+sub helper_type { 'HashRef' }
 
 no Moose;
 
 # register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Collection::Hash;
+package Moose::Meta::Attribute::Custom::Collection::Hash;
 sub register_implementation { 'MooseX::AttributeHelpers::Collection::Hash' }
 
 
@@ -32,7 +37,7 @@ MooseX::AttributeHelpers::Collection::Hash
   package Stuff;
   use Moose;
   use MooseX::AttributeHelpers;
-
+  
   has 'options' => (
       metaclass => 'Collection::Hash',
       is        => 'ro',
@@ -40,17 +45,17 @@ MooseX::AttributeHelpers::Collection::Hash
       default   => sub { {} },
       provides  => {
           'set'    => 'set_option',
-          'get'    => 'get_option',
+          'get'    => 'get_option',            
           'empty'  => 'has_options',
           'count'  => 'num_options',
           'delete' => 'delete_option',
       }
   );
-
+  
 =head1 DESCRIPTION
 
-This module provides a Hash attribute which provides a number of
-hash-like operations. See L<MooseX::AttributeHelpers::MethodProvider::Hash>
+This module provides an Array attribute which provides a number of 
+array operations. See L<MooseX::AttributeHelpers::MethodProvider::Hash>
 for more details.
 
 =head1 METHODS
@@ -69,7 +74,7 @@ for more details.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
+All complex software has bugs lurking in it, and this module is no 
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
@@ -79,11 +84,11 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
+=cut
\ No newline at end of file
