@@ -2,18 +2,23 @@
 package MooseX::AttributeHelpers::Collection::List;
 use Moose;
 
-our $VERSION   = '0.17';
-$VERSION = eval $VERSION;
+our $VERSION   = '0.01';
 our $AUTHORITY = 'cpan:STEVAN';
 
-extends 'Moose::Meta::Attribute';
-with 'MooseX::AttributeHelpers::Trait::Collection::List';
+use MooseX::AttributeHelpers::MethodProvider::List;
+
+extends 'MooseX::AttributeHelpers::Collection';
+
+has '+method_provider' => (
+    default => 'MooseX::AttributeHelpers::MethodProvider::List'
+);
+
+sub helper_type { 'ArrayRef' }
 
 no Moose;
 
 # register the alias ...
-package # hide me from search.cpan.org
-    Moose::Meta::Attribute::Custom::Collection::List;
+package Moose::Meta::Attribute::Custom::Collection::List;
 sub register_implementation { 'MooseX::AttributeHelpers::Collection::List' }
 
 
@@ -40,7 +45,7 @@ MooseX::AttributeHelpers::Collection::List
       default   => sub { [] },
       provides  => {
           map  => 'map_options',
-          grep => 'filter_options',
+          grep => 'fitler_options',
       }
   );
 
@@ -54,8 +59,6 @@ for more details.
 
 =over 4
 
-=item B<meta>
-
 =item B<method_provider>
 
 =item B<has_method_provider>
@@ -76,7 +79,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+Copyright 2007 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
